==> ejc-budgetmanage-impl-3.0.0-20220325.144208-24-sources.jar: com/ejianc/business/bedget/bean/MaterialrequirementsdetailEntity.java <==
package com.ejianc.business.bedget.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 物资需求总计划子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_budgetmanage_materialrequirementsdetail")
public class MaterialrequirementsdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 物资编号
    @TableField(value="name")
    private java.lang.String name; // 物资名称
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private java.lang.Long changeId; // 变更单据id
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="spec")
    private java.lang.String spec; // 物资规格
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="base")
    private java.lang.String base; // 基础
    @TableField(value="main")
    private java.math.BigDecimal main; // 主体
    @TableField(value="decorate")
    private java.math.BigDecimal decorate; // 装修
    @TableField(value="subtotal")
    private java.math.BigDecimal subtotal; // 小计
    @TableField(value="other_num")
    private java.math.BigDecimal otherNum; // 其它数量
    @TableField(value="total")
    private java.math.BigDecimal total; // 合计数量
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注


    /**
     * 主表id
     * @return
     */
    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 物资编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 物资编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 物资名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 物资规格
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 物资规格
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }
    /**
     * 基础
     */
    public java.lang.String getBase() {
        return base;
    }

    /**
     * 基础
     */
    public void setBase(java.lang.String base) {
        this.base = base;
    }
    /**
     * 主体
     */
    public java.math.BigDecimal getMain() {
        return main;
    }

    /**
     * 主体
     */
    public void setMain(java.math.BigDecimal main) {
        this.main = main;
    }
    /**
     * 装修
     */
    public java.math.BigDecimal getDecorate() {
        return decorate;
    }

    /**
     * 装修
     */
    public void setDecorate(java.math.BigDecimal decorate) {
        this.decorate = decorate;
    }
    /**
     * 小计
     */
    public java.math.BigDecimal getSubtotal() {
        return subtotal;
    }

    /**
     * 小计
     */
    public void setSubtotal(java.math.BigDecimal subtotal) {
        this.subtotal = subtotal;
    }
    /**
     * 其它数量
     */
    public java.math.BigDecimal getOtherNum() {
        return otherNum;
    }

    /**
     * 其它数量
     */
    public void setOtherNum(java.math.BigDecimal otherNum) {
        this.otherNum = otherNum;
    }
    /**
     * 合计数量
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计数量
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}

==> ejc-budgetmanage-impl-3.0.0-20220406.092419-64-sources.jar: com/ejianc/business/bedget/bean/MaterialrequirementsdetailEntity.java <==
package com.ejianc.business.bedget.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

import java.math.BigDecimal;

/**
 * 物资需求总计划子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_budgetmanage_materialrequirementsdetail")
public class MaterialrequirementsdetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value="mid")
    private java.lang.Long mid; // 主表id
    @TableField(value="bill_code")
    private java.lang.String billCode; // 物资编号
    @TableField(value="name")
    private java.lang.String name; // 物资名称
    @TableField(value="bill_state")
    private java.lang.Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="change_id")
    private java.lang.Long changeId; // 变更单据id
    @TableField(value="change_state")
    private java.lang.String changeState; // 变更状态，1:未变更;2:变更中;3:已变更
    @TableField(value="spec")
    private java.lang.String spec; // 物资规格
    @TableField(value="measuring_unit")
    private java.lang.String measuringUnit; // 计量单位
    @TableField(value="base")
    private java.math.BigDecimal base; // 基础
    @TableField(value="main")
    private java.math.BigDecimal main; // 主体
    @TableField(value="decorate")
    private java.math.BigDecimal decorate; // 装修
    @TableField(value="subtotal")
    private java.math.BigDecimal subtotal; // 小计
    @TableField(value="other_num")
    private java.math.BigDecimal otherNum; // 其它数量
    @TableField(value="total")
    private java.math.BigDecimal total; // 合计数量
    @TableField(value="remarks")
    private java.lang.String remarks; // 备注


    /**
     * 主表id
     * @return
     */
    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    /**
     * 物资编号
     */
    public java.lang.String getBillCode() {
        return billCode;
    }

    /**
     * 物资编号
     */
    public void setBillCode(java.lang.String billCode) {
        this.billCode = billCode;
    }
    /**
     * 物资名称
     */
    public java.lang.String getName() {
        return name;
    }

    /**
     * 物资名称
     */
    public void setName(java.lang.String name) {
        this.name = name;
    }
    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public java.lang.Integer getBillState() {
        return billState;
    }

    /**
     * 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
     */
    public void setBillState(java.lang.Integer billState) {
        this.billState = billState;
    }
    /**
     * 变更单据id
     */
    public java.lang.Long getChangeId() {
        return changeId;
    }

    /**
     * 变更单据id
     */
    public void setChangeId(java.lang.Long changeId) {
        this.changeId = changeId;
    }
    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public java.lang.String getChangeState() {
        return changeState;
    }

    /**
     * 变更状态，1:未变更;2:变更中;3:已变更
     */
    public void setChangeState(java.lang.String changeState) {
        this.changeState = changeState;
    }
    /**
     * 物资规格
     */
    public java.lang.String getSpec() {
        return spec;
    }

    /**
     * 物资规格
     */
    public void setSpec(java.lang.String spec) {
        this.spec = spec;
    }
    /**
     * 计量单位
     */
    public java.lang.String getMeasuringUnit() {
        return measuringUnit;
    }

    /**
     * 计量单位
     */
    public void setMeasuringUnit(java.lang.String measuringUnit) {
        this.measuringUnit = measuringUnit;
    }

    public BigDecimal getBase() {
        return base;
    }

    public void setBase(BigDecimal base) {
        this.base = base;
    }

    /**
     * 主体
     */
    public java.math.BigDecimal getMain() {
        return main;
    }

    /**
     * 主体
     */
    public void setMain(java.math.BigDecimal main) {
        this.main = main;
    }
    /**
     * 装修
     */
    public java.math.BigDecimal getDecorate() {
        return decorate;
    }

    /**
     * 装修
     */
    public void setDecorate(java.math.BigDecimal decorate) {
        this.decorate = decorate;
    }
    /**
     * 小计
     */
    public java.math.BigDecimal getSubtotal() {
        return subtotal;
    }

    /**
     * 小计
     */
    public void setSubtotal(java.math.BigDecimal subtotal) {
        this.subtotal = subtotal;
    }
    /**
     * 其它数量
     */
    public java.math.BigDecimal getOtherNum() {
        return otherNum;
    }

    /**
     * 其它数量
     */
    public void setOtherNum(java.math.BigDecimal otherNum) {
        this.otherNum = otherNum;
    }
    /**
     * 合计数量
     */
    public java.math.BigDecimal getTotal() {
        return total;
    }

    /**
     * 合计数量
     */
    public void setTotal(java.math.BigDecimal total) {
        this.total = total;
    }
    /**
     * 备注
     */
    public java.lang.String getRemarks() {
        return remarks;
    }

    /**
     * 备注
     */
    public void setRemarks(java.lang.String remarks) {
        this.remarks = remarks;
    }
    
}
